@@ -1,6 +1,6 @@
  /* SVN FILE INFO
- * $Revision: 453 $ : Last Committed Revision
- * $Date: 2010-05-07 14:31:08 -0700 (Fri, 07 May 2010) $ : Last Committed Date */
+ * $Revision: 522 $ : Last Committed Revision
+ * $Date: 2010-06-11 16:52:39 -0700 (Fri, 11 Jun 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -220,7 +220,6 @@ agent_New(void)
 agent_NewBinary( struct mc_platform_s *mc_platform)
 {
   agent_p agent; 
-  int err_code;
 
   /* malloc memory for the agent */
   agent = (MCAgent_t)malloc(sizeof(agent_t));
@@ -351,7 +350,7 @@ agent_Initialize(
           return NULL;
         }
         if (mc_platform->default_agentstatus != -1) {
-          agent->agent_status = mc_platform->default_agentstatus;
+          agent->agent_status = (enum MC_AgentStatus_e)mc_platform->default_agentstatus;
         }
         break;
       case RETURN_MSG:
@@ -437,7 +436,7 @@ agent_Destroy(agent_p agent)
   if (agent->agent_status == MC_AGENT_NEUTRAL) {
     if ((agent->agent_interp) != NULL) {
       Ch_Reset(*agent->agent_interp);
-			interpreter_queue_Add(agent->mc_platform->interpreter_queue, agent->agent_interp);
+			interpreter_queue_Add(agent->mc_platform->interpreter_queue, (struct AP_GENERIC_s*)agent->agent_interp);
     }
   }
   free(agent->lock);
@@ -494,7 +493,7 @@ agent_ChScriptInitVar(ChInterp_t* interp)
   char *tmp_buf;
 
   /* Declare special variables for holding the agent id and name */
-  tmp_buf = malloc(sizeof(char) * 200);
+  tmp_buf = (char*)malloc(sizeof(char) * 200);
   tmp_buf[0] = '\0';
   sprintf(tmp_buf, "int mc_agent_id = -1;");
   Ch_DeclareVar(
@@ -622,6 +621,32 @@ agent_ChScriptInitVar(ChInterp_t* interp)
       (ChFuncdl_t)MC_AclWaitRetrieve_chdl
       );
   /* begin Acl Helper Functions */
+  Ch_DeclareFunc(
+      *interp,
+      "int mc_AclGetProtocol(void* acl_message);",
+      (ChFuncdl_t)MC_AclGetProtocol_chdl
+      );
+  Ch_DeclareFunc(
+      *interp,
+      "char* mc_AclGetConversationID(void* acl_message);",
+      (ChFuncdl_t)MC_AclGetConversationID_chdl
+      );
+  Ch_DeclareFunc(
+      *interp,
+      "int mc_AclGetPerformative(void* acl_message);",
+      (ChFuncdl_t)MC_AclGetPerformative_chdl
+      );
+  Ch_DeclareFunc(
+      *interp,
+      "int mc_AclGetSender(void* acl_message, char** name, char** address);",
+      (ChFuncdl_t)MC_AclGetSender_chdl
+      );
+  Ch_DeclareFunc(
+      *interp,
+      "char* mc_AclGetContent(void* acl_message);",
+      (ChFuncdl_t)MC_AclGetContent_chdl
+      );
+
   Ch_DeclareFunc(
       *interp,
       "int mc_AclSetProtocol(void* acl_message, int protocol);",
@@ -663,6 +688,11 @@ agent_ChScriptInitVar(ChInterp_t* interp)
       "int mc_AddAgent(void* agent);",
       (ChFuncdl_t)MC_AddAgent_chdl
       );
+  Ch_DeclareFunc(
+      *interp,
+      "int mc_AgentAddTask(void* agent, const char* code, const char* return_var_name, const char* server, int persistent);",
+      (ChFuncdl_t)MC_AgentAddTask_chdl
+      );
   Ch_DeclareFunc(
       *interp,
       "const void* mc_AgentVariableRetrieve(void* agent, const char* var_name, int task_num);",
@@ -701,7 +731,22 @@ agent_ChScriptInitVar(ChInterp_t* interp)
   Ch_DeclareFunc(
       *interp,
       "MCAgent_t mc_ComposeAgentS(const char* name, *home, *owner, *code, *return_var_name, *server, *workgroup_code, int persistent);",
-      (ChFuncdl_t)MC_ComposeAgentS_chdl
+      (ChFuncdl_t)MC_ComposeAgentWithWorkgroup_chdl
+      );
+  Ch_DeclareFunc(
+      *interp,
+      "MCAgent_t mc_ComposeAgentWithWorkgroup(const char* name, *home, *owner, *code, *return_var_name, *server, *workgroup_code, int persistent);",
+      (ChFuncdl_t)MC_ComposeAgentWithWorkgroup_chdl
+      );
+  Ch_DeclareFunc(
+      *interp,
+      "MCAgent_t mc_ComposeAgentFromFile(const char* name, *home, *owner, *filename, *return_var_name, *server, int persistent);",
+      (ChFuncdl_t)MC_ComposeAgentFromFile_chdl
+      );
+  Ch_DeclareFunc(
+      *interp,
+      "MCAgent_t mc_ComposeAgentFromFileWithWorkgroup(const char* name, *home, *owner, *filename, *return_var_name, *server, *workgroup_code, int persistent);",
+      (ChFuncdl_t)MC_ComposeAgentFromFileWithWorkgroup_chdl
       );
   Ch_DeclareFunc(
       *interp,
@@ -918,7 +963,7 @@ agent_ChScriptInitVar(ChInterp_t* interp)
       (ChFuncdl_t)MC_GetAgentName_chdl
       );
 
-  return;
+  return NULL;
 }
 
 #ifndef _WIN32
@@ -940,7 +985,6 @@ agent_RunChScriptThread(void* ChAgent)
   char *ChShellArg[2];
   void *result;
   int progress;
-  char *tmp_buf;
   interpreter_variable_data_t* temp_interp_data;
 
   /* set up the agent object */
@@ -960,10 +1004,11 @@ agent_RunChScriptThread(void* ChAgent)
   }
 
   /* Get an interpreter from the list of agency interpreters */
-  agent->agent_interp = interpreter_queue_CreateRetrieve(mc_platform->interpreter_queue,
+  agent->agent_interp = (ChInterp_t *)interpreter_queue_CreateRetrieve(mc_platform->interpreter_queue,
 		agent->mc_platform->interp_options );
   if(agent->agent_interp == NULL) {
     /* Could not get a new interpreter. Abort. */
+    WARN("Could not initialize another Ch interperter. Please make more copies of the chmt*.dl file.\n");
     return NULL;
   }
 
@@ -1058,6 +1103,9 @@ agent_RunChScriptThread(void* ChAgent)
     MUTEX_LOCK(agent->run_lock);
     if(Ch_RunScript(*agent->agent_interp, ChShellArg) < 0) {
       fprintf(stderr, "Ch_RunScript error. %s:%d\n", __FILE__, __LINE__);
+    } else {
+      /* Flush the output buffer, in case the agent printed anything */
+      fflush(stdout);
     }
 
     /* if(Ch_CallFuncByName(((MCAgent_t)ChAgent)->agent_interp, "main", NULL))
@@ -1075,7 +1123,10 @@ agent_RunChScriptThread(void* ChAgent)
   }
 
   /* now add the data element returned from the Ch execution into the agent data structure */
-  if(strcmp(agent->datastate->tasks[progress]->var_name, "no-return"))
+  if(
+      agent->datastate->tasks[progress]->var_name != NULL &&
+      strcmp(agent->datastate->tasks[progress]->var_name, "no-return")
+    )
   {
     result = interpreter_variable_data_InitializeFromAgent(agent);
     /* Free old result extracted from XML agent */
@@ -1084,7 +1135,7 @@ agent_RunChScriptThread(void* ChAgent)
         );
     /* Replace with new freshly calculated one */
     agent->datastate->tasks[progress]->agent_return_data = 
-      result;
+      (interpreter_variable_data_t*)result;
   } else {
     interpreter_variable_data_Destroy(
         agent->datastate->tasks[progress]->agent_return_data );
@@ -1094,9 +1145,12 @@ agent_RunChScriptThread(void* ChAgent)
   /* This is where we want to save all of the agent variables that the agent
    * wishes to keep for its trip. */
   while (
-	temp_interp_data = agent_variable_list_Pop(
-		agent->datastate->tasks[progress]->agent_variable_list )
-	) {
+	  (
+      temp_interp_data = 
+      agent_variable_list_Pop(agent->datastate->tasks[progress]->agent_variable_list)
+    )
+	) 
+  {
 	interpreter_variable_data_Destroy(temp_interp_data);
   }
   for(i = 0; i < agent->datastate->tasks[progress]->num_saved_variables; i++) {
@@ -1133,7 +1187,7 @@ agent_RunChScriptThread(void* ChAgent)
     if ((((MCAgent_t)ChAgent)->agent_interp) != NULL) {
       /* Reset the interpreter and put it back into the queue */
       Ch_Reset(*agent->agent_interp);
-      interpreter_queue_Add(mc_platform->interpreter_queue, agent->agent_interp);
+      interpreter_queue_Add(mc_platform->interpreter_queue, (struct AP_GENERIC_s*)agent->agent_interp);
     }
 
     /* Perform some housekeeping regarding agent status */
