@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 402 $ : Last Committed Revision
- * $Date: 2009-08-23 13:44:39 -0700 (Sun, 23 Aug 2009) $ : Last Committed Date */
+ * $Revision: 517 $ : Last Committed Revision
+ * $Date: 2010-06-11 12:06:47 -0700 (Fri, 11 Jun 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -75,14 +75,14 @@ agent_task_Copy(agent_task_p task)
 	cp_task->persistent = task->persistent;
 	cp_task->init_agent_status = task->init_agent_status;
 
-	cp_task->var_name = malloc
+	cp_task->var_name = (char*)malloc
 		(
 		 sizeof(char) * 
 		 (strlen(task->var_name) + 1)
 		);
 	strcpy(cp_task->var_name, task->var_name);
 
-	cp_task->server_name = malloc
+	cp_task->server_name = (char*)malloc
 		(
 		 sizeof(char) * 
 		 (strlen(task->server_name) + 1)
@@ -90,7 +90,7 @@ agent_task_Copy(agent_task_p task)
 	strcpy(cp_task->server_name, task->server_name);
 
 	if (task->code_id != NULL) {
-		cp_task->code_id = malloc
+		cp_task->code_id = (char*)malloc
 			(
 			 sizeof(char) * 
 			 (strlen(task->code_id) + 1)
@@ -107,13 +107,13 @@ agent_task_Copy(agent_task_p task)
 	/* Copy the agent variable list */
 	cp_task->agent_variable_list = agent_variable_list_New();
 	for(i = 0; i < task->agent_variable_list->size; i++) {
-		interp_data = ListSearch(
-				task->agent_variable_list,
+		interp_data = (interpreter_variable_data_t*)ListSearch(
+				(list_p)task->agent_variable_list,
 				i );
 		if (interp_data == NULL) { continue; }
 		interp_data = interpreter_variable_data_Copy(interp_data);
 		ListAdd(
-				cp_task->agent_variable_list,
+				(list_p)cp_task->agent_variable_list,
 				interp_data
 				);
 	}
