@@ -190,7 +190,8 @@ cmd_prompt_Thread( LPVOID arg )
 #ifdef HAVE_LIBREADLINE
         buf = readline("MobileC > ");
         if (buf == NULL) {
-          break;
+          sleep(5);
+          continue;
         }
         if (*buf) {
             add_history(buf);
@@ -204,6 +205,7 @@ cmd_prompt_Thread( LPVOID arg )
 #endif
             {
                 fprintf(stderr, "fgets failed at %s:%d\n", __FILE__, __LINE__);
+                Sleep(5000);
             }
 #endif
         /* Get rid of newline character */
