@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 453 $ : Last Committed Revision
- * $Date: 2010-05-07 14:31:08 -0700 (Fri, 07 May 2010) $ : Last Committed Date */
+ * $Revision: 517 $ : Last Committed Revision
+ * $Date: 2010-06-11 12:06:47 -0700 (Fri, 11 Jun 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -204,7 +204,7 @@ agent_queue_Flush(agent_queue_p queue)
     if (node != NULL) {
       printf("flushing agent id %d: name:%s status:%d\n",
           (int)node->id, node->name, node->agent_status);
-      agent_queue_RemoveIndex(queue->list, i);
+      agent_queue_RemoveIndex((agent_queue_p)queue->list, i);
     }
   }
   MUTEX_UNLOCK(queue->lock);
@@ -256,7 +256,6 @@ AP_QUEUE_STD_DEFN_TEMPLATE(
     )
 
 /* Interpreter Queue */
-AP_GENERIC_p AP_GENERIC_Copy(AP_GENERIC_p AP_GENERIC);
 
 AP_QUEUE_STD_DEFN_TEMPLATE(
 		interpreter_queue,
@@ -270,7 +269,7 @@ AP_GENERIC_p interpreter_queue_CreateRetrieve( struct interpreter_queue_s *queue
 	ChInterp_t* interp;
 	MUTEX_LOCK(queue->lock);
 	if (queue->size <= 0) {
-		interp = malloc(sizeof(ChInterp_t));
+		interp = (ChInterp_t*)malloc(sizeof(ChInterp_t));
 		if( Ch_Initialize(interp, interp_options) != CH_OK) {
       /* Could not initialize another interpreter */
       MUTEX_UNLOCK(queue->lock);
@@ -278,11 +277,11 @@ AP_GENERIC_p interpreter_queue_CreateRetrieve( struct interpreter_queue_s *queue
     }
     /* Initialize the agent intepreter variables */
     agent_ChScriptInitVar(interp);
-		ret = interp;
+		ret = (struct AP_GENERIC_s*)interp;
 		MUTEX_UNLOCK(queue->lock);
 		return ret;
 	}
-	ret = ListPop(queue->list);
+	ret = (struct AP_GENERIC_s*)ListPop(queue->list);
 	queue->size--;
 	COND_SIGNAL(queue->cond);
 	MUTEX_UNLOCK(queue->lock);
