@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 402 $ : Last Committed Revision
- * $Date: 2009-08-23 13:44:39 -0700 (Sun, 23 Aug 2009) $ : Last Committed Date */
+ * $Revision: 517 $ : Last Committed Revision
+ * $Date: 2010-06-11 12:06:47 -0700 (Fri, 11 Jun 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -78,7 +78,7 @@ agent_xml_parse__mobile_agent
     return MC_ERR_PARSE;
   }
   /* There is only one child node: AGENT_DATA*/
-  xml_parser->node = (const mxml_node_t*)xml_get_child(
+  xml_parser->node = xml_get_child(
       xml_parser->node,
       "AGENT_DATA",
       1);
@@ -307,7 +307,7 @@ agent_xml_parse__tasks(agent_p agent, xml_parser_p xml_parser)
   int code_num=0;
   int err_code;
   const char* attribute;
-  const mxml_node_t* tasks_node;
+  mxml_node_t* tasks_node;
   char buf[20];
 
   tasks_node = xml_parser->node;
@@ -328,7 +328,7 @@ agent_xml_parse__tasks(agent_p agent, xml_parser_p xml_parser)
 
   /* parse the 'num' attribute */
   attribute = mxmlElementGetAttr(
-      (mxml_node_t*)tasks_node,
+      tasks_node,
       "num"
       );
   if (attribute == NULL) {
@@ -433,7 +433,7 @@ agent_xml_parse__tasks(agent_p agent, xml_parser_p xml_parser)
     return MC_ERR_PARSE;
   }
 
-  return 0;
+  return (error_code_t)0;
 }
 
 /* *** */
@@ -442,7 +442,7 @@ error_code_t
 agent_xml_parse__task(agent_p agent, xml_parser_p xml_parser, int index)
 {
   const char* attribute;
-  const mxml_node_t* task_node;
+  mxml_node_t* task_node;
   error_code_t err_code = MC_SUCCESS;
   CHECK_NULL(xml_parser->node, return MC_ERR_PARSE;);
   task_node = xml_parser->node;
@@ -488,7 +488,7 @@ agent_xml_parse__task(agent_p agent, xml_parser_p xml_parser, int index)
       (mxml_node_t*)task_node,
       "code_id");
   if (attribute != NULL) {
-    agent->datastate->tasks[index]->code_id = malloc
+    agent->datastate->tasks[index]->code_id = (char*)malloc
       (
        sizeof(char) * 
        (strlen(attribute) + 1)
@@ -539,7 +539,7 @@ agent_xml_parse__data(agent_p agent, xml_parser_p xml_parser, int index)
 {
   const char* attribute;
   const char* attribute2;
-  const mxml_node_t *data_node;
+  mxml_node_t *data_node;
   int data_type_size;
   interpreter_variable_data_t* interp_variable;
   if (xml_parser->node == NULL) {
@@ -871,7 +871,7 @@ void agent_xml_parse__fill_row_data(
 error_code_t
 agent_xml_parse__agent_code(agent_p agent, int index, xml_parser_p xml_parser)
 {
-  char *attribute;
+  const char *attribute;
   int cur_task = agent->datastate->task_progress;
   if( cur_task == agent->datastate->number_of_tasks )
     cur_task--;
@@ -888,14 +888,14 @@ agent_xml_parse__agent_code(agent_p agent, int index, xml_parser_p xml_parser)
      "id"
     );
   if (attribute) {
-    agent->datastate->agent_code_ids[index] = malloc
+    agent->datastate->agent_code_ids[index] = (char*)malloc
       (
        sizeof(char) * 
        (strlen(attribute) + 1)
       );
     strcpy(agent->datastate->agent_code_ids[index], attribute);
   } else {
-    agent->datastate->agent_code_ids[index] = malloc(sizeof(char));
+    agent->datastate->agent_code_ids[index] = (char*)malloc(sizeof(char));
     *(agent->datastate->agent_code_ids[index]) = '\0';
   }
   if (agent->datastate->tasks[cur_task]->code_id && attribute != NULL) {
@@ -914,28 +914,28 @@ agent_return_xml_parse(agent_p agent)
 {
   xml_parser_t xml_parser;
   xml_parser.root = agent->datastate->xml_root;
-  xml_parser.node = (const mxml_node_t*)xml_get_child(
+  xml_parser.node = xml_get_child(
       xml_parser.root,
       "NAME",
       1);
       
   agent_xml_parse__name(agent, &xml_parser);
 
-  xml_parser.node = (const mxml_node_t*)xml_get_child(
+  xml_parser.node = xml_get_child(
       xml_parser.root,
       "OWNER",
       1);
 
   agent_xml_parse__owner(agent, &xml_parser);
 
-  xml_parser.node = (const mxml_node_t*)xml_get_child(
+  xml_parser.node = xml_get_child(
       xml_parser.root,
       "HOME",
       1);
 
   agent_xml_parse__home(agent, &xml_parser);
 
-  xml_parser.node = (const mxml_node_t*)xml_get_child(
+  xml_parser.node = xml_get_child(
       xml_parser.root,
       "TASK",
       1);
@@ -947,7 +947,7 @@ agent_return_xml_parse(agent_p agent)
 error_code_t
 message_xml_parse(message_p message)
 {
-  int err_code;
+  error_code_t err_code;
   xml_parser_p xml_parser;
   xml_parser = (xml_parser_p)malloc(sizeof(xml_parser_t));
   xml_parser->root = message->xml_root;
@@ -987,7 +987,7 @@ message_xml_parse(message_p message)
     err_code = MC_ERR_PARSE;
     goto cleanup;
   }
-  xml_parser->node = (const mxml_node_t*)xml_get_child
+  xml_parser->node = xml_get_child
     (
      xml_parser->node,
      "MESSAGE",
